@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use base 'Exporter';
 
+use UNIVERSAL::require;
 use Net::IP qw(:PROC);
 
 use FusionInventory::Agent::Tools;
@@ -20,6 +21,7 @@ our @EXPORT = qw(
     getNetworkMaskIPv6
     hex2canonical
     alt2canonical
+    resolv
 );
 
 my $hex_byte = qr/[0-9A-F]{2}/i;
@@ -71,6 +73,7 @@ sub getSubnetAddressIPv6 {
 
 sub hex2canonical {
     my ($address) = @_;
+    return unless $address;
 
     my @bytes = $address =~ /^(?:0x)?(..)(..)(..)(..)$/;
     return join('.', map { hex($_) } @bytes);
@@ -78,6 +81,7 @@ sub hex2canonical {
 
 sub alt2canonical {
     my ($address) = @_;
+    return unless $address;
 
     my @bytes = $address =~ /^(?:0x)?(..)(..)(..)(..)(..)(..)$/;
     return join(':', @bytes);
@@ -99,6 +103,40 @@ sub getNetworkMaskIPv6 {
     return ip_compress_address(ip_bintoip(ip_get_mask($prefix, 6), 6), 6);
 }
 
+sub resolv {
+    my ($string, $logger) = @_;
+
+    my @ret;
+
+    Socket::GetAddrInfo->require();
+    Socket->require();
+
+    my ($error, @results) = Socket::GetAddrInfo::getaddrinfo(
+        $string, "", { socktype => Socket::SOCK_RAW() }
+    );
+    if ($error && $logger) {
+        $logger->error("unable to resolve `$string': $error");
+        next;
+    }
+
+    # and push all of their addresses in the list
+    foreach my $result (@results) {
+        my ($error, $host) = Socket::GetAddrInfo::getnameinfo(
+            $result->{addr},
+            Socket::GetAddrInfo::NI_NUMERICHOST(),
+        );
+        # Drop the zone index. Net::IP do not support them
+        $host =~ s/%.*$//;
+        if ($error && $logger) {
+            $logger->error("unable to get host `$host' IP address: $error");
+            next;
+        }
+        push @ret, Net::IP->new($host);
+    }
+
+    return @ret;
+}
+
 1;
 __END__
 
@@ -153,3 +191,7 @@ Returns the network mask for IPv4.
 =head2 getNetworkMaskIPv6($prefix)
 
 Returns the network mask for IPv6.
+
+=head2 resolv($string)
+
+Returns an array of Net::IP for the given $string
